import processing.pdf.*;

int radius = 100;
int xPosition = 20;
int pos = 0;

int [][] dataMatrix = null;
int maxCount;
int numRows, numColumns;
int cellWidth, cellHeight, cellMarginHorizontal, cellMarginVertical, rowSpacing;

String [] deweyNames = new String[10];
PFont fontHeader = createFont("SukhumvitSet-SemiBold", 30, true);
PFont fontHeader2 = createFont("SourceSansPro-Semibold", 14, true);
PFont fontHeader3 = createFont("SukhumvitSet-SemiBold", 16, true);
PFont fontBracket = createFont("SourceSansPro-Regular", 80, true);
PFont fontMain = createFont("SourceSansPro-Semibold", 12, true);

color bgColor, textColor;

Table myTable;

void setup()
{
  size(1200, 900);
  // size(3600, 2700, PDF, "output1.pdf");
  smooth();
  cellWidth = 70;
  cellHeight = 5;
  cellMarginHorizontal = 220;
  cellMarginVertical = 140;
  rowSpacing = 60;

  bgColor = color(234, 233, 237);

  println("setup done");

  //    myTable = new Table();
  myTable = loadTable("hw1_yearmonth.csv", "header");

  numRows = myTable.getRowCount();
  numColumns = myTable.getColumnCount() - 2;

  dataMatrix = new int[numRows][numColumns];
  maxCount = dataMatrix[0][0];

  for (int i = 0; i < numRows; i++)
  {
    for (int j = 0; j < numColumns; j++) //skipping two columns j=2
    {
      dataMatrix[i][j] = myTable.getInt(i, (j+2));
      print(dataMatrix[i][j] + " " );
      //            print(i + "," + j + " " );

      if (dataMatrix[i][j] > maxCount)
        maxCount = dataMatrix[i][j];
    }
    println();
  }



  println("Rows: " + numRows + ", Columns: " + numColumns + ", max: " + maxCount);
  println();
  println();

  deweyNames[0] = "Agriculture & related technology";
  deweyNames[1] = "Apparatus, equipment, materials";
  deweyNames[2] = "Plant injuries, diseases, pests";
  deweyNames[3] = "Field & plantation crops";
  deweyNames[4] = "Orchards, fruits, forestry";
  deweyNames[5] = "Garden crops, horticulture";
  deweyNames[6] = "Animal husbandry";
  deweyNames[7] = "Processing dairy";
  deweyNames[8] = "Insect culture";
  deweyNames[9] = "Hunting, fishing, conservation";
}


void draw()
{
  background(bgColor);
  noStroke();

  for (int i = 0; i < numColumns; i++)
  {
    for (int j = 0; j < 12; j++)
    {
      for (int k = 0; k < 8; k++)
      {
        colorMode(HSB);
        float fillColor = 255 * dataMatrix[(k+(j*8))][i] / maxCount;
//        fill(255*i/12 + (k*1), fillColor, (fillColor));
        fill(255*i/12 + (k*1), 255, (fillColor+30), (fillColor*20)+20);

        rect(cellMarginHorizontal + j * cellWidth * 1, cellMarginVertical + (k * (cellHeight)) + (i * 60), 
        cellWidth, cellHeight);
        fill(255, 100);
        //            text("   " + (k+(8*j)) + ", " + (i) + " = " + dataMatrix[(k+(8*j))][i], j * 50, (k * 7) + (i * 82) + 8);
        //            text("   " + (255*(i/12)) + " ", j * 50, (k * 7) + (i * 82) + 8);
        colorMode(RGB);
      }
    }
  }

  // Y label
  textFont(fontMain);
  fill(84, 81, 109);
  for (int i = 0; i < numColumns; i++)
  {
    textFont(fontHeader3);
    textAlign(RIGHT);
    text("63" + i, cellMarginHorizontal-10, cellMarginVertical + (i * rowSpacing) + 15);
    textFont(fontMain);
    textLeading(14);
    text(deweyNames[i], cellMarginHorizontal-10, cellMarginVertical + (i * rowSpacing) + 35);
  }
  for (int i = 0; i < 13; i++)  //vertical lines
  {
    if (i > 0) 
      text(i, (cellMarginHorizontal - 35) + (i*71), height-(cellMarginVertical*1.2)); //X label
    stroke(84, 81, 109, 100);
    if (i != 0 && i != 12)
      line(cellMarginHorizontal + (i*70), cellMarginVertical, cellMarginHorizontal + (i*70), cellMarginVertical + (118*cellHeight));
  }
  for (int i = 0; i< numColumns; i++)  //horizontal lines
  {
    stroke(84, 81, 109, 100);
    line(cellMarginHorizontal-100, cellMarginVertical + cellHeight*8 + (i*rowSpacing), 
    width-(cellMarginHorizontal*.64), cellMarginVertical + cellHeight*8 + (i*rowSpacing));
  }

  //TITLE
  textFont(fontHeader);
  textAlign(LEFT);
  text("Urban Agriculture in Seattle", cellMarginHorizontal, cellMarginVertical - 40);

  textFont(fontHeader2);
  text("Number of items checked out monthly with Dewey Decimal classifcation 630: Agriculture, 2006-2013", 
  cellMarginHorizontal, cellMarginVertical - 20);

  // LEGEND
  textFont(fontMain);
  pushMatrix();
  textAlign(LEFT);
  translate(width-(cellMarginHorizontal*.4), cellMarginVertical);
  textLeading(14);
  translate(0, 32);
  text("Checkouts\nper month", -35, -25);

  colorMode(HSB);
  noStroke();
  for (int i = 0; i<50; i++)
  {
    float fillColor = log((255*i)/49)*45;
    fill(120, 255, fillColor+30, (fillColor*20)+20);
    rect(-cellWidth*.5, i*cellHeight, cellWidth*.2, cellHeight);
  }
  stroke(84, 81, 109, 130);
  fill(0, 0);
  rect(-cellWidth*.5, 0, cellWidth*.2, cellHeight*50);

  translate(0, 10); 
  for (int i = 0; i<5; i++)
  {
    fill(84, 81, 109);
    text(i*1000, -15, i * 60);
  } 
  colorMode(RGB);
  popMatrix();
  exit();

  //    pushMatrix();
  //    translate(cellMarginHorizontal * .45, height/2);
  //    rotate(radians(-90));
  //    text("Dewey Number", 0, 0);
  //    popMatrix();
  //    
  //    pushMatrix();
  //    translate(width/2 - cellMarginHorizontal*1.7, 830);
  //    text("Month",0,0);
  //    popMatrix();
  //    
  //    textFont(fontBracket);
  //    text("}", 970, 780);
  //    textFont(fontHeader2);
  //    text("Year, 2006-2013", 1030, 763);
  //
}

